# GLOBAL VARIABLES ----
utils::globalVariables(
    c("new_data", "object", "factor_count", "fail_check", "unique_count",
      "key", "..indicator", "bad_class", ".key", ".index", ".pred", ".value",
      ".conf_hi", ".conf_lo", ".fitted", ".type", "actual", "prediction",
      ".estimate", ".estimator", ".metric", ".model", ".nested.col",
      "value", ".model_desc", ".model_id", "shapiro_wilk", "durbin_watson",
      ".actual", ".calibration_data", ".prediction", ".ci",
      "yhat", ".model_desc_new", ".model_desc_old", ".model_desc_user",
      ".model_table", ".model_table_clean", ".residuals", ".is_null", ".",
      ".final_values", ".idx_values", ".pred_values", ".row_id", "..row_id", "rowid..",
      "id", ".id", "this_model", "wflow_id", "rowid", "value.x", "value.y",
      "..rowid", ".actual_data", "n", ".modeltime_tables", ".error_desc",
      "x", "d", "f", ".forecast", ".pred_res")
)
